@@ -16,14 +16,14 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
 #include "config.h"
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <packagekit-glib/packagekit.h>
+#include <packagekit-glib2/packagekit.h>
 
 #include "egg-debug.h"
 #include "egg-string.h"
@@ -54,6 +54,8 @@ static const PkEnumMatch enum_info_icon_name[] = {
 	{PK_INFO_ENUM_FINISHED,			"dialog-information"},
 	{PK_INFO_ENUM_REINSTALLING,		"dialog-information"},
 	{PK_INFO_ENUM_DOWNGRADING,		"pk-package-update"},
+	{PK_INFO_ENUM_PREPARING,		"dialog-information"},
+	{PK_INFO_ENUM_DECOMPRESSING,		"dialog-information"},
 	{0, NULL}
 };
 
@@ -94,6 +96,7 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
+	{PK_STATUS_ENUM_COPY_FILES,		"pk-package-info"},
 	{0, NULL}
 };
 
@@ -134,6 +137,7 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_SCAN_PROCESS_LIST,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_EXECUTABLE_FILES,	"pk-package-info"},
 	{PK_STATUS_ENUM_CHECK_LIBRARIES,	"pk-package-info"},
+	{PK_STATUS_ENUM_COPY_FILES,		"pk-package-info"},
 	{0, NULL}
 };
 
@@ -326,7 +330,7 @@ gpk_media_type_enum_to_localised_text (PkMediaTypeEnum type)
  * gpk_error_enum_to_localised_text:
  **/
 const gchar *
-gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
+gpk_error_enum_to_localised_text (PkErrorEnum code)
 {
 	const gchar *text = NULL;
 	switch (code) {
@@ -517,7 +521,7 @@ gpk_error_enum_to_localised_text (PkErrorCodeEnum code)
  * gpk_error_enum_to_localised_message:
  **/
 const gchar *
-gpk_error_enum_to_localised_message (PkErrorCodeEnum code)
+gpk_error_enum_to_localised_message (PkErrorEnum code)
 {
 	const gchar *text = NULL;
 	switch (code) {
@@ -881,9 +885,7 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 		text = _("Automatic cleanup is being ignored");
 		break;
 	case PK_MESSAGE_ENUM_REPO_METADATA_DOWNLOAD_FAILED:
-		text = _("The package download failed");
-/* string-freeze: uncomment better translation */
-//		text = _("Software source download failed");
+		text = _("Software source download failed");
 		break;
 	default:
 		egg_warning ("message unrecognised: %i", message);
@@ -900,131 +902,131 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 	const gchar *text = NULL;
 	switch (status) {
 	case PK_STATUS_ENUM_UNKNOWN:
-		/* TRANSLATORS: This is when the status is not known */
+		/* TRANSLATORS: This is when the transaction status is not known */
 		text = _("Unknown state");
 		break;
 	case PK_STATUS_ENUM_SETUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, the daemon is in the process of starting */
 		text = _("Starting");
 		break;
 	case PK_STATUS_ENUM_WAIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, the transaction is waiting for another to complete */
 		text = _("Waiting in queue");
 		break;
 	case PK_STATUS_ENUM_RUNNING:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, just started */
 		text = _("Running");
 		break;
 	case PK_STATUS_ENUM_QUERY:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, is querying data */
 		text = _("Querying");
 		break;
 	case PK_STATUS_ENUM_INFO:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, getting data from a server */
 		text = _("Getting information");
 		break;
 	case PK_STATUS_ENUM_REMOVE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, removing packages */
 		text = _("Removing packages");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading package files */
 		text = _("Downloading packages");
 		break;
 	case PK_STATUS_ENUM_INSTALL:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, installing packages */
 		text = _("Installing packages");
 		break;
 	case PK_STATUS_ENUM_REFRESH_CACHE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, refreshing internal lists */
 		text = _("Refreshing software list");
 		break;
 	case PK_STATUS_ENUM_UPDATE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, installing updates */
 		text = _("Installing updates");
 		break;
 	case PK_STATUS_ENUM_CLEANUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, removing old packages, and cleaning config files */
 		text = _("Cleaning up packages");
 		break;
 	case PK_STATUS_ENUM_OBSOLETE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, obsoleting old packages */
 		text = _("Obsoleting packages");
 		break;
 	case PK_STATUS_ENUM_DEP_RESOLVE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, checking the transaction before we do it */
 		text = _("Resolving dependencies");
 		break;
 	case PK_STATUS_ENUM_SIG_CHECK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, checking if we have all the security keys for the operation */
 		text = _("Checking signatures");
 		break;
 	case PK_STATUS_ENUM_ROLLBACK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we return to a previous system state */
 		text = _("Rolling back");
 		break;
 	case PK_STATUS_ENUM_TEST_COMMIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're doing a test transaction */
 		text = _("Testing changes");
 		break;
 	case PK_STATUS_ENUM_COMMIT:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're writing to the system package database */
 		text = _("Committing changes");
 		break;
 	case PK_STATUS_ENUM_REQUEST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, requesting data from a server */
 		text = _("Requesting data");
 		break;
 	case PK_STATUS_ENUM_FINISHED:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, all done! */
 		text = _("Finished");
 		break;
 	case PK_STATUS_ENUM_CANCEL:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, in the process of cancelling */
 		text = _("Cancelling");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_REPOSITORY:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading repository information");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_PACKAGELIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading list of packages");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_FILELIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading file lists");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_CHANGELOG:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading lists of changes");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_GROUP:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading groups");
 		break;
 	case PK_STATUS_ENUM_DOWNLOAD_UPDATEINFO:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, downloading metadata */
 		text = _("Downloading update information");
 		break;
 	case PK_STATUS_ENUM_REPACKAGING:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, repackaging delta files */
 		text = _("Repackaging files");
 		break;
 	case PK_STATUS_ENUM_LOADING_CACHE:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, loading databases */
 		text = _("Loading cache");
 		break;
 	case PK_STATUS_ENUM_SCAN_APPLICATIONS:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, scanning for running processes */
 		text = _("Scanning installed applications");
 		break;
 	case PK_STATUS_ENUM_GENERATE_PACKAGE_LIST:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, generating a list of packages installed on the system */
 		text = _("Generating package lists");
 		break;
 	case PK_STATUS_ENUM_WAITING_FOR_LOCK:
-		/* TRANSLATORS: The transaction state */
+		/* TRANSLATORS: transaction state, when we're waiting for the native tools to exit */
 		text = _("Waiting for package manager lock");
 		break;
 	case PK_STATUS_ENUM_WAITING_FOR_AUTH:
@@ -1043,6 +1045,10 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		/* TRANSLATORS: we are checking for libraries in use */
 		text = _("Checking for libraries currently in use");
 		break;
+	case PK_STATUS_ENUM_COPY_FILES:
+		/* TRANSLATORS: we are copying package files to prepare to install */
+		text = _("Copying files");
+		break;
 	default:
 		egg_warning ("status unrecognised: %s", pk_status_enum_to_text (status));
 	}
@@ -1179,6 +1185,14 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in present tense */
 		text = _("Reinstalling");
 		break;
+	case PK_INFO_ENUM_PREPARING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Preparing");
+		break;
+	case PK_INFO_ENUM_DECOMPRESSING:
+		/* TRANSLATORS: The action of the package, in present tense */
+		text = _("Decompressing");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1221,6 +1235,14 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 		/* TRANSLATORS: The action of the package, in past tense */
 		text = _("Reinstalled");
 		break;
+	case PK_INFO_ENUM_PREPARING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Prepared");
+		break;
+	case PK_INFO_ENUM_DECOMPRESSING:
+		/* TRANSLATORS: The action of the package, in past tense */
+		text = _("Decompressed");
+		break;
 	default:
 		egg_warning ("info unrecognised: %s", pk_info_enum_to_text (info));
 	}
@@ -1769,8 +1791,8 @@ gpk_message_enum_to_icon_name (PkMessageEnum message)
 const gchar *
 gpk_info_status_enum_to_text (GpkInfoStatusEnum info)
 {
-	if (info > PK_INFO_ENUM_UNKNOWN)
-		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_UNKNOWN);
+	if (info >= PK_INFO_ENUM_LAST)
+		return gpk_info_enum_to_localised_past (info - PK_INFO_ENUM_LAST);
 	return gpk_info_enum_to_localised_present (info);
 }
 
@@ -1788,8 +1810,8 @@ gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 		return "pk-package-installed";
 
 	/* use normal icon as a fallback */
-	if (info > PK_INFO_ENUM_UNKNOWN)
-		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_UNKNOWN);
+	if (info >= PK_INFO_ENUM_LAST)
+		return gpk_info_enum_to_icon_name (info - PK_INFO_ENUM_LAST);
 
 	/* regular PkInfoEnum */
 	return gpk_info_enum_to_icon_name (info);
