@@ -41,15 +41,12 @@ main (int argc, char *argv[])
 {
 	GOptionContext *context;
 	gboolean ret;
-	gboolean verbose = FALSE;
 	GError *error = NULL;
 	gchar **files = NULL;
 	DBusGConnection *connection;
 	DBusGProxy *proxy = NULL;
 
 	const GOptionEntry options[] = {
-		{ "verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose,
-		  _("Show extra debugging information"), NULL },
 		{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &files,
 		  /* TRANSLATORS: command line option: a list of files to install */
 		  _("Files to install"), NULL },
@@ -65,18 +62,18 @@ main (int argc, char *argv[])
 	if (! g_thread_supported ())
 		g_thread_init (NULL);
 	g_type_init ();
+	gtk_init (&argc, &argv);
 
 	/* TRANSLATORS: program name: application to install a package to provide a file */
 	g_set_application_name (_("PackageKit File Installer"));
 	context = g_option_context_new ("gpk-install-file");
 	g_option_context_set_summary (context, _("PackageKit File Installer"));
 	g_option_context_add_main_entries (context, options, NULL);
+	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
 
-	egg_debug_init (verbose);
-	gtk_init (&argc, &argv);
-
 	/* TRANSLATORS: title to pass to to the user if there are not enough privs */
 	ret = gpk_check_privileged_user (_("Local file installer"), TRUE);
 	if (!ret)
@@ -114,7 +111,7 @@ main (int argc, char *argv[])
 	ret = dbus_g_proxy_call (proxy, "InstallPackageFiles", &error,
 				 G_TYPE_UINT, 0, /* xid */
 				 G_TYPE_STRV, files, /* data */
-				 G_TYPE_STRING, "hide-finished", /* interaction */
+				 G_TYPE_STRING, "hide-finished,hide-warnings", /* interaction */
 				 G_TYPE_INVALID,
 				 G_TYPE_INVALID);
 	if (!ret && !gpk_ignore_session_error (error)) {
